@@ -1,6 +1,8 @@
 import logging
+import os
 import sys
 import time
+from functools import partial
 from multiprocessing import Process
 
 from mss import mss
@@ -26,13 +28,18 @@ def capture_screenshots(delay):
         i += 1
 
 
-if __name__ == '__main__':
+def main():
+
     delay = int(sys.argv[1])
-    process = Process(
-        target=capture_screenshots,
-        args=(delay,),
-        name="Make screenshots"
-    )
-    process.daemon = True
-    process.start()
-    logger.info(f"Process was started with {process.pid}")
+    capture_screenshots(delay)
+    # process = Process(
+    #     target=partial(capture_screenshots, delay),
+    # )
+    # process.daemon = True
+    # process.start()
+    # process.join()
+    # print(f"Process was started with {process.pid}")
+
+
+if __name__ == '__main__':
+    main()
